@@ -14,9 +14,9 @@ from basetrainer.utils import plot_utils
 
 
 def test_callback_for_build_scheduler(num_epochs, num_steps, optimizer, lr_init, milestones, num_warn_up):
-    # scheduler = "ExpLR"  # cosine,multi-step
+    scheduler = "ExpLR"  # cosine,multi-step
     # scheduler = "LambdaLR"  # cosine,multi-step
-    scheduler = "cosine"  # cosine,multi-step
+    # scheduler = "cosine"  # cosine,multi-step
     lr_scheduler = build_scheduler.get_scheduler(scheduler,
                                                  optimizer=optimizer,
                                                  lr_init=lr_init,
@@ -58,10 +58,10 @@ def test_torch_scheduler(num_epochs, num_steps, optimizer, lr_init, milestones,
 
 
 if __name__ == "__main__":
-    num_epochs = 200
+    num_epochs = 50
     num_warn_up = 3
     lr_init = 0.01
-    num_steps = 10
+    num_steps = 256
     milestones = []
     # milestones = [50, 100, 120]
     model = models.resnet18(pretrained=False)
